@@ -1,19 +1,12 @@
-import os
 import asyncio
-import functools
 
-from pyrogram import Client , filters
+from pyrogram import Client , filters 
 from pyrogram.errors import FloodWait
-from pyrogram.types import Message , CallbackQuery , ChatPrivileges
+from pyrogram.types import CallbackQuery  ,ChatMemberUpdated
 
 from typing import Union
 from functools import wraps
 
-from d4rk.Logs import setup_logger
-
-
-logger = setup_logger(__name__)
-
 command_registry = []
 last_index_per_chat = {}
 bot_order_per_chat = {}
@@ -39,7 +32,8 @@ def new_task():
     def decorator(func):
         @wraps(func)
         async def wrapper(*args, **kwargs):
-            asyncio.create_task(func(*args, **kwargs))
+            task = asyncio.create_task(func(*args, **kwargs))
+            return await task
         return wrapper
     return decorator
 
@@ -47,10 +41,14 @@ def retry():
     def decorator(func):
         @wraps(func)
         async def wrapper(*args, **kwargs):
-            try:await func(*args, **kwargs)
-            except FloodWait as e:
-                await asyncio.sleep(e.value)
-                await func(*args, **kwargs)
+            async def runner():
+                try:return await func(*args, **kwargs)
+                except FloodWait as e:
+                    await asyncio.sleep(e.value)
+                    try:return await func(*args, **kwargs)
+                    except:pass
+            task = asyncio.create_task(runner())
+            return await task
         return wrapper
     return decorator
 
@@ -58,11 +56,18 @@ def round_robin():
     def decorator(func):
         @wraps(func)
         async def wrapper(client, message):
-            chat_id = message.chat.id
-            msg_id = message.id
+
+            if isinstance(message, ChatMemberUpdated):
+                chat_id = message.chat.id
+                msg_id = message.date
+            else:
+                chat_id = message.chat.id
+                msg_id = message.id
+
             
             if message.chat.type.name.lower() == "private":
-                return await func(client, message)
+                task = asyncio.create_task(func(client, message))
+                return await task
 
             if chat_id not in bot_order_per_chat:
                 bot_order_per_chat[chat_id] = [client.me.id]
@@ -80,14 +85,14 @@ def round_robin():
                 selected_bot_id = bot_order_per_chat[chat_id][current_index]
 
                 if client.me.id == selected_bot_id:
-                    result = await func(client, message)
+                    task = asyncio.create_task(func(client, message))
+                    result = await task
                     responded_messages[chat_id].add(msg_id)
                     last_index_per_chat[chat_id] = (current_index + 1) % len(bot_order_per_chat[chat_id])
                     return result
         return wrapper
     return decorator
 
-
 def command(command: Union[str, list], description: str,Custom_filter=None):
     def decorator(func):
         command_registry.append({
@@ -95,7 +100,6 @@ def command(command: Union[str, list], description: str,Custom_filter=None):
             "description": description,
             "handler": func
         })
-        logger.info(f"Registered command: {command} - {description}")
         if Custom_filter:
             filter = filters.command(command) & Custom_filter
         else:
@@ -109,3 +113,16 @@ def command(command: Union[str, list], description: str,Custom_filter=None):
         return wrapper
     return decorator
 
+def button(pattern: str ='',CustomFilters: filters = None):
+    def decorator(func):
+        regex_pattern = rf"^{pattern}"
+        if CustomFilters is None:
+            filter = filters.regex(regex_pattern)
+        else:
+            filter = filters.regex(regex_pattern) & CustomFilters
+        @Client.on_callback_query(filter)
+        @wraps(func)
+        async def wrapper(client: Client, callback_query: CallbackQuery):
+            asyncio.create_task(func(client, callback_query))
+        return wrapper
+    return decorator
